==> Zipper-0.0.1.zip: Zipper/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'Zipper';
$lang['postinstall'] = 'Post Install Message.';
$lang['postuninstall'] = 'Post Uninstall Message, e.g., "Curses! Foiled Again!"';
$lang['really_uninstall'] = 'Really? Are you sure
you want to unsinstall this fine module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['moddescription'] = 'This module helps making zip files easily.';

$lang['error'] = 'Error!';
$land['admin_title'] = 'Zipper Admin Panel';
$lang['admindescription'] = '';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['postinstall'] = 'Post Install Message, (e.g., Be sure to set "" permissions to use this module!)';


$lang['changelog'] = '<ul>
<li>Version 0.0.1 - 28 June 2010. Initial Release.</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module helps making zip files easily.</p>
<h3>How Do I Use It</h3>
<p>This module requires ZipArchive and Zip extension (see doc: http://be2.php.net/manual/en/book.zip.php)</p>
<h3>Use it in frontend</h3>
<p>To use it in the frontend, you have to follow the following steps:</p>
<h4>1. Prepare the list of files</h4>
<p>Invoque the action "prepare" ({Zipper action="prepare" stack="mystack" filename="/my/path/filename.txt"})for each files you want to add in the zip file. You have to use the param "stack" which is the global name of your zip file and the param "filename" (absolute or from the uploads path or from the root path). You can also specify the param "path" (with starting and ending "/").</p>
<h4>2. Build the file</h4>
<p>When you are ready, call the default action ({Zipper stack="mystack"}). It return the filename in case of success. You can specify a desired filename for the zip with the param "filename".</p>
<h3>How to use it from another module ? (In the code itself...)</h3>
<p>You can use the function ZipArray(array $files, $filename = ""). The $files array must be a relational 2d array. Keys are the path and value are the system filenames.</p>
<p>You can also use the dirToArray($directory, $recursive = true, $path = "/") function to generate the files array from an existing directory.</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2010, Jean-Christophe Cuvelier <a href="mailto:jcc@morris-chapman.com">&lt;jcc@morris-chapman.com&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';

$lang['ziparchive_notfound'] = 'This module requires PHP ZipArchive library. Please read the module help for more information.';
$lang['module_is_working'] = 'The module is working.';
$lang['download_module'] = 'Download the self generated module zip file.';
$lang['define_stack_and_filename'] = 'Please define at least params "Stack" and "Filename".';
$lang['define_stack'] = 'Please define at least param "Stack".';
?>

==> Zipper-0.0.3.zip: Zipper/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'Zipper';
$lang['postinstall'] = 'Post Install Message.';
$lang['postuninstall'] = 'Post Uninstall Message, e.g., "Curses! Foiled Again!"';
$lang['really_uninstall'] = 'Really? Are you sure
you want to unsinstall this fine module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['moddescription'] = 'This module helps making zip files easily.';

$lang['error'] = 'Error!';
$land['admin_title'] = 'Zipper Admin Panel';
$lang['admindescription'] = '';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['postinstall'] = 'Post Install Message, (e.g., Be sure to set "" permissions to use this module!)';


$lang['changelog'] = '<ul>
<li>Version 0.0.1 - 28 June 2010. Initial Release.</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module helps making zip files easily.</p>
<h3>How Do I Use It</h3>
<p>This module requires ZipArchive and Zip extension (see doc: http://be2.php.net/manual/en/book.zip.php)</p>
<h3>Use it in frontend</h3>
<p>To use it in the frontend, you have to follow the following steps:</p>
<h4>1. Prepare the list of files</h4>
<p>Invoque the action "prepare" ({Zipper action="prepare" stack="mystack" filename="/my/path/filename.txt"})for each files you want to add in the zip file. You have to use the param "stack" which is the global name of your zip file and the param "filename" (absolute or from the uploads path or from the root path). You can also specify the param "path" (with starting and ending "/").</p>
<h4>2. Build the file</h4>
<p>When you are ready, call the default action ({Zipper stack="mystack"}). It return the filename in case of success. You can specify a desired filename for the zip with the param "filename".</p>
<h3>How to use it from another module ? (In the code itself...)</h3>
<p>You can use the function ZipArray(array $files, $filename = ""). The $files array must be a relational 2d array. Keys are the path and value are the system filenames.</p>
<p>You can also use the dirToArray($directory, $recursive = true, $path = "/") function to generate the files array from an existing directory.</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2010, Jean-Christophe Cuvelier <a href="mailto:jcc@morris-chapman.com">&lt;jcc@morris-chapman.com&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';

$lang['ziparchive_notfound'] = 'This module requires PHP ZipArchive library. Please read the module help for more information.';
$lang['module_is_working'] = 'The module is working.';
$lang['download_module'] = 'Download the self generated module zip file.';
$lang['define_stack_and_filename'] = 'Please define at least params "Stack" and "Filename".';
$lang['define_stack'] = 'Please define at least param "Stack".';
$lang['error_with_file'] = 'Error: The file "%s" do not exists';
$lang['error_during_zipping'] = 'OMG: An error occured during the "Zipping" operation !';
?>
